package com.usky.demo.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.exception.BusinessException;
import com.usky.common.core.util.BeanMapperUtils;
import com.usky.common.core.util.FileUtils;
import com.usky.common.core.util.GlobalUtils;
import com.usky.demo.RemoteTsdbProxyService;
import com.usky.demo.domain.*;
import com.usky.demo.service.QueryInfluxdbDataService;
import com.usky.demo.service.SysUserService;
import com.usky.system.RemoteUserService;
import com.usky.system.domain.SysUserVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

@RestController
public class DataTsdbProxyControllerApi implements RemoteTsdbProxyService {

    @Autowired
    private QueryInfluxdbDataService queryInfluxdbDataService;

    /**
     * 单个设备数据写入
     * @return
     */
    @Override
    public ApiResult<Void> sendDeviceData(DeviceDataWriteVO writeVO){
        queryInfluxdbDataService.sendDeviceData(writeVO);
        return ApiResult.success();
    }

    /**
     * 单个设备实时数据查询
     * @param productCode
     * @param deviceId
     * @return
     */
    @Override
    public ApiResult<LastResultVO> queryLastDeviceData(String productCode,
                                                       String deviceId){
        return ApiResult.success(queryInfluxdbDataService.queryLastDeviceData(productCode,deviceId));
    }

    /**
     * 批量设备实时数据查询
     * @param requestVO
     * @return
     */
    @Override
    public ApiResult<List<LastResultVO>> queryLastDeviceData(LastRequestVO requestVO){
        return ApiResult.success(queryInfluxdbDataService.queryLastDeviceData(requestVO));
    }

    /**
     * 单个设备历史数据查询
     * @param productCode
     * @param deviceId
     * @param startTime
     * @param endTime
     * @return
     */
    @Override
    public ApiResult<HistoryResultVO> queryHistoryDeviceData(String productCode,
                                                             String deviceId,
                                                             String startTime,
                                                             String endTime){
        return ApiResult.success(queryInfluxdbDataService.queryHistoryDeviceData(productCode,deviceId,startTime,endTime));
    }

    /**
     * 批量设备历史数据查询
     * @param requestVO
     * @return
     */
    @Override
    public ApiResult<List<HistoryResultVO>> queryHistoryDeviceData(HistoryRequestVO requestVO){
        return ApiResult.success(queryInfluxdbDataService.queryHistoryDeviceData(requestVO));
    }
}
